Documentation
¶
Overview ¶
Package ociclient provides an implementation of ociregistry.Interface that uses HTTP to talk to the remote registry.
Index ¶
Constants ¶
const DefaultListPageSize = 1000
DefaultListPageSize holds the default number of results to request when using the list endpoints. It's not more than 1000 because AWS ECR complains it it's more than that.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Options ¶
type Options struct {
// DebugID is used to prefix any log messages printed by the client.
DebugID string
// Transport is used to make HTTP requests. The context passed
// to its RoundTrip method will have an appropriate
// [ociauth.RequestInfo] value added, suitable for consumption
// by the transport created by [ociauth.NewStdTransport]. If
// Transport is nil, [http.DefaultTransport] will be used.
Transport http.RoundTripper
// Insecure specifies whether an http scheme will be used to
// address the host instead of https.
Insecure bool
// ListPageSize configures the maximum number of results
// requested when making list requests. If it's <= zero, it
// defaults to DefaultListPageSize.
ListPageSize int
}
Click to show internal directories.
Click to hide internal directories.